==> robomotion_app-0.2.0.tar.gz: lib/dialog_block.dart <==
import 'package:flutter/material.dart';
import 'parser.dart';
import 'dart:convert';

//ignore: must_be_immutable
class DialogBlock extends StatefulWidget {
  final String block;
  final bool disabled;

  ButtonParser buttonParser = ButtonParser();
  DividerParser dividerParser = DividerParser();
  HeaderParser headerParser = HeaderParser();
  ImageParser imageParser = ImageParser();
  SectionParser sectionParser = SectionParser();
  SpacerParser spacerParser = SpacerParser();
  DragDropParser dragDropParser = DragDropParser();
  PlainTextInputParser plainTextInputParser = PlainTextInputParser();
  CheckboxParser checkboxParser = CheckboxParser();
  RadioButtonParser radioButtonParser = RadioButtonParser();
  DateTimePickerParser dateTimePickerParser = DateTimePickerParser();

  DialogBlock(this.block,
      {buttonParser,
      dividerParser,
      headerParser,
      imageParser,
      sectionParser,
      spacerParser,
      dragDropParser,
      plainTextInputParser,
      checkboxParser,
      radioButtonParser,
      dateTimePickerParser,
      this.disabled = false}) {
    this.buttonParser = buttonParser ?? this.buttonParser;
    this.dividerParser = dividerParser ?? this.dividerParser;
    this.headerParser = headerParser ?? this.headerParser;
    this.imageParser = imageParser ?? this.imageParser;
    this.sectionParser = sectionParser ?? this.sectionParser;
    this.spacerParser = spacerParser ?? this.spacerParser;
    this.dragDropParser = dragDropParser ?? this.dragDropParser;
    this.plainTextInputParser = plainTextInputParser ?? this.plainTextInputParser;
    this.checkboxParser = checkboxParser ?? this.checkboxParser;
    this.radioButtonParser = radioButtonParser ?? this.radioButtonParser;
    this.dateTimePickerParser = dateTimePickerParser ?? this.dateTimePickerParser;
  }

  @override
  createState() => DialogBlockState();
}

class DialogBlockState extends State<DialogBlock> {
  List<Widget> renderBlock(BuildContext context) {
    var json = jsonDecode(widget.block);
    List<Widget> widgets = [];

    for (var block in json["blocks"]) {
      var blockType = block["type"];
      Widget? widget;
      switch (blockType) {
        case "section":
          widget = renderSectionBlock(context, block);
          break;

        case "actions":
          widget = renderActionsBlock(context, block);
          break;

        case "divider":
          widget = renderDividerBlock(context, block);
          break;

        case "image":
          widget = renderImageBlock(context, block);
          break;

        case "context":
          widget = renderContextBlock(context, block);
          break;

        case "header":
          widget = renderHeaderBlock(context, block);
          break;

        case "file":
          widget = renderFileBlock(context, block);
          break;

        case "input":
          widget = renderInputBlock(context, block);
          break;
      }

      if (widget != null) {
        widgets.add(widget);
      }
    }

    return widgets;
  }

  Widget renderSectionBlock(BuildContext context, block) {
    return widget.sectionParser.parse(block, context: context);
  }

  Widget renderActionsBlock(BuildContext context, block) {
    List elements = block["elements"];
    List<Widget> actionWidgets = [];

    int i = 0;
    for (Map element in elements as Iterable<Map<dynamic, dynamic>>) {
      switch (element["type"]) {
        case "button":
          var mL = i == 0 ? 0.0 : 8.0;
          var mR = i == elements.length - 1 ? 0.0 : 8.0;
          actionWidgets.add(widget.buttonParser.parse(element,
              context: context,
              options: Options(margin: EdgeInsets.fromLTRB(mL, 8, mR, 8), disabled: widget.disabled)));
          break;

        case "spacer":
          actionWidgets.add(widget.spacerParser.parse(element, context: context));
          break;

        case "file":
          actionWidgets.add(renderFileBlock(context, element));
          break;

        case "input":
          actionWidgets.add(renderInputBlock(context, element));
          break;

        case "checkboxes":
          actionWidgets.add(renderCheckboxesBlock(context, element));
          break;

        case "radio_buttons":
          actionWidgets.add(renderRadioButtons(context, element));
          break;

        case "datepicker":
          actionWidgets.add(renderDateTimePicker(context, element));
          break;

        case "section":
          actionWidgets.add(renderSectionBlock(context, element));
          break;

        default:
          break;
      }
      i++;
    }

    return Container(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: actionWidgets,
      ),
    );
  }

  Widget renderDividerBlock(BuildContext context, block) {
    return widget.dividerParser.parse(block, context: context);
  }

  Widget renderImageBlock(BuildContext context, block) {
    return widget.imageParser.parse(block, context: context);
  }

  Widget renderContextBlock(BuildContext context, block) {
    return Container();
  }

  Widget renderHeaderBlock(BuildContext context, block) {
    return widget.headerParser.parse(block, context: context);
  }

  Widget renderFileBlock(BuildContext context, block) {
    var file = block["file"];
    var innerType = file["type"];
    switch (innerType) {
      case "drag_drop":
        return widget.dragDropParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  Widget renderInputBlock(BuildContext context, block) {
    var element = block["element"];
    var innerType = element["type"];

    switch (innerType) {
      case "plain_text_input":
        return widget.plainTextInputParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  Widget renderCheckboxesBlock(BuildContext context, block) {
    return widget.checkboxParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  Widget renderRadioButtons(BuildContext context, block) {
    return widget.radioButtonParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  Widget renderDateTimePicker(BuildContext context, block) {
    return widget.dateTimePickerParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(16),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: renderBlock(context),
      ),
    );
  }
}

==> robomotion_app-0.3.0.tar.gz: lib/dialog_block.dart <==
import 'package:flutter/material.dart';
import 'parser.dart';
import 'dart:convert';

//ignore: must_be_immutable
class DialogBlock extends StatefulWidget {
  final String block;
  final bool disabled;

  ButtonParser buttonParser = ButtonParser();
  DividerParser dividerParser = DividerParser();
  HeaderParser headerParser = HeaderParser();
  ImageParser imageParser = ImageParser();
  SectionParser sectionParser = SectionParser();
  SpacerParser spacerParser = SpacerParser();
  DragDropParser dragDropParser = DragDropParser();
  PlainTextInputParser plainTextInputParser = PlainTextInputParser();
  CheckboxParser checkboxParser = CheckboxParser();
  RadioButtonParser radioButtonParser = RadioButtonParser();
  DateTimePickerParser dateTimePickerParser = DateTimePickerParser();
  DropDownListParser dropdownListParser = DropDownListParser();

  DialogBlock(this.block,
      {buttonParser,
      dividerParser,
      headerParser,
      imageParser,
      sectionParser,
      spacerParser,
      dragDropParser,
      plainTextInputParser,
      checkboxParser,
      radioButtonParser,
      dateTimePickerParser,
      dropdownListParser,
      this.disabled = false}) {
    this.buttonParser = buttonParser ?? this.buttonParser;
    this.dividerParser = dividerParser ?? this.dividerParser;
    this.headerParser = headerParser ?? this.headerParser;
    this.imageParser = imageParser ?? this.imageParser;
    this.sectionParser = sectionParser ?? this.sectionParser;
    this.spacerParser = spacerParser ?? this.spacerParser;
    this.dragDropParser = dragDropParser ?? this.dragDropParser;
    this.plainTextInputParser = plainTextInputParser ?? this.plainTextInputParser;
    this.checkboxParser = checkboxParser ?? this.checkboxParser;
    this.radioButtonParser = radioButtonParser ?? this.radioButtonParser;
    this.dateTimePickerParser = dateTimePickerParser ?? this.dateTimePickerParser;
    this.dropdownListParser = dropdownListParser ?? this.dropdownListParser;
  }

  @override
  createState() => DialogBlockState();
}

class DialogBlockState extends State<DialogBlock> {
  List<Widget> renderBlock(BuildContext context) {
    var json = jsonDecode(widget.block);
    List<Widget> widgets = [];

    for (var block in json["blocks"]) {
      var blockType = block["type"];
      Widget? widget;
      switch (blockType) {
        case "section":
          widget = renderSectionBlock(context, block);
          break;

        case "actions":
          widget = renderActionsBlock(context, block);
          break;

        case "divider":
          widget = renderDividerBlock(context, block);
          break;

        case "image":
          widget = renderImageBlock(context, block);
          break;

        case "context":
          widget = renderContextBlock(context, block);
          break;

        case "header":
          widget = renderHeaderBlock(context, block);
          break;

        case "file":
          widget = renderFileBlock(context, block);
          break;

        case "input":
          widget = renderInputBlock(context, block);
          break;
      }

      if (widget != null) {
        widgets.add(widget);
      }
    }

    return widgets;
  }

  Widget renderSectionBlock(BuildContext context, block) {
    return widget.sectionParser.parse(block, context: context);
  }

  Widget renderActionsBlock(BuildContext context, block) {
    List elements = block["elements"];
    List<Widget> actionWidgets = [];

    int i = 0;
    for (Map element in elements) {
      switch (element["type"]) {
        case "button":
          var mL = i == 0 ? 0.0 : 8.0;
          var mR = i == elements.length - 1 ? 0.0 : 8.0;
          actionWidgets.add(widget.buttonParser.parse(element,
              context: context,
              options: Options(margin: EdgeInsets.fromLTRB(mL, 8, mR, 8), disabled: widget.disabled)));
          break;

        case "spacer":
          actionWidgets.add(widget.spacerParser.parse(element, context: context));
          break;

        case "file":
          actionWidgets.add(renderFileBlock(context, element));
          break;

        case "input":
          actionWidgets.add(renderInputBlock(context, element));
          break;

        case "checkboxes":
          actionWidgets.add(renderCheckboxesBlock(context, element));
          break;

        case "radio_buttons":
          actionWidgets.add(renderRadioButtons(context, element));
          break;

        case "datepicker":
          actionWidgets.add(renderDateTimePicker(context, element));
          break;

        case "section":
          actionWidgets.add(renderSectionBlock(context, element));
          break;

        case "dropdown-list":
          actionWidgets.add(renderDropdownListBlock(context, element));
          break;

        default:
          break;
      }
      i++;
    }

    return Container(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: actionWidgets,
      ),
    );
  }

  Widget renderDividerBlock(BuildContext context, block) {
    return widget.dividerParser.parse(block, context: context);
  }

  Widget renderImageBlock(BuildContext context, block) {
    return widget.imageParser.parse(block, context: context);
  }

  Widget renderContextBlock(BuildContext context, block) {
    return Container();
  }

  Widget renderHeaderBlock(BuildContext context, block) {
    return widget.headerParser.parse(block, context: context);
  }

  Widget renderFileBlock(BuildContext context, block) {
    var file = block["file"];
    var innerType = file["type"];
    switch (innerType) {
      case "drag_drop":
        return widget.dragDropParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }
    return Container();
  }

  Widget renderInputBlock(BuildContext context, block) {
    var element = block["element"];
    var innerType = element["type"];

    switch (innerType) {
      case "plain_text_input":
        return widget.plainTextInputParser.parse(block, context: context, options: Options(disabled: widget.disabled));
    }

    return Container();
  }

  Widget renderCheckboxesBlock(BuildContext context, block) {
    return widget.checkboxParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  Widget renderRadioButtons(BuildContext context, block) {
    return widget.radioButtonParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  Widget renderDateTimePicker(BuildContext context, block) {
    return widget.dateTimePickerParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  Widget renderDropdownListBlock(BuildContext context, block) {
    return widget.dropdownListParser.parse(block, context: context, options: Options(disabled: widget.disabled));
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.all(16),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: renderBlock(context),
      ),
    );
  }
}
